==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/user/messages/eu/profile.php <==
<?php
return array (
  '%y Years' => '',
  '<b>This profile stream is still empty!</b>' => '',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '',
  '<strong>About</strong> this user' => '',
  '<strong>Profile</strong> menu' => '',
  'About' => 'Buruz',
  'Allow other selection' => '',
  'Birthday' => '',
  'Birthday field options' => '',
  'Checkbox' => '',
  'Checkbox List' => '',
  'Checkbox field options' => '',
  'City' => '',
  'Comma separated country codes, e.g. DE,EN,AU' => '',
  'Communication' => '',
  'Country' => '',
  'Created at' => '',
  'Created by' => '',
  'Creation date of the user' => '',
  'Date' => '',
  'Date(-time) field options' => '',
  'Datetime' => '',
  'Default value' => '',
  'Description' => '',
  'Diverse' => '',
  'E-Mail' => '',
  'E-mail address of the user' => '',
  'Edit account' => '',
  'Editable' => '',
  'Facebook URL' => '',
  'Fax' => '',
  'Female' => '',
  'Field Type could not be changed!' => '',
  'Fieldtype' => '',
  'First name' => '',
  'Followers' => '',
  'Following' => '',
  'Friends' => 'Lagunak',
  'Gender' => '',
  'General' => 'Orokorra',
  'Hide age per default' => '',
  'Hide year in profile' => '',
  'ID' => '',
  'Instagram URL' => '',
  'Internal Name' => '',
  'Internal name already in use!' => '',
  'Internal name could not be changed!' => '',
  'Invalid field type!' => '',
  'Invalid!' => '',
  'LDAP Attribute' => '',
  'Last login date of the user' => '',
  'Last name' => '',
  'Link Prefix (e.g. https://, mailto:, tel://)' => '',
  'LinkedIn URL' => '',
  'Male' => '',
  'Markdown' => '',
  'Maximum length' => '',
  'Maximum value' => '',
  'Minimum length' => '',
  'Minimum value' => '',
  'Mobile' => '',
  'Module' => '',
  'Must contain at least one character.' => '',
  'Number' => '',
  'Number field options' => '',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => '',
  'Only alphanumeric characters allowed!' => '',
  'Other:' => '',
  'Phone Private' => '',
  'Phone Work' => '',
  'Please select:' => '',
  'Possible values' => '',
  'Profile Field Category' => '',
  'Regular Expression: Error message' => '',
  'Regular Expression: Validator' => '',
  'Required' => '',
  'Searchable' => '',
  'Select List' => '',
  'Select field options' => '',
  'Show at registration' => '',
  'Show date/time picker' => '',
  'Social bookmarks' => '',
  'Sort order' => '',
  'Spaces' => 'Espazioak',
  'State' => '',
  'Stream' => '',
  'Street' => '',
  'Supported ISO3166 country codes' => '',
  'Text' => '',
  'Text Area' => '',
  'Text Field Options' => '',
  'Text area field options' => '',
  'This profile is no longer available!' => '',
  'This user account is not approved yet!' => '',
  'This will add an additional input element for custom values' => '',
  'TikTok URL' => '',
  'Title' => '',
  'Translation Category ID' => '',
  'Twitter URL' => '',
  'Type Config' => '',
  'Updated at' => '',
  'Updated by' => '',
  'Use as Directory filter' => '',
  'Username' => '',
  'Validator' => '',
  'Vimeo URL' => '',
  'Visible' => '',
  'Website URL' => '',
  'XMPP Jabber Address' => '',
  'Xing URL' => '',
  'You need to login to view this user profile!' => '',
  'YouTube URL' => '',
  'Zip' => '',
  '{attribute} is required!' => '',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/user/messages/eu/profile.php <==
<?php
return array (
  '%y Years' => '',
  '<b>This profile stream is still empty!</b>' => '',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '',
  '<strong>About</strong> this user' => '',
  '<strong>Profile</strong> menu' => '',
  'About' => 'Buruz',
  'Allow other selection' => '',
  'Birthday' => '',
  'Birthday field options' => '',
  'Checkbox' => '',
  'Checkbox List' => '',
  'Checkbox field options' => '',
  'City' => '',
  'Comma separated country codes, e.g. DE,EN,AU' => '',
  'Communication' => '',
  'Country' => '',
  'Created at' => '',
  'Created by' => '',
  'Creation date of the user' => '',
  'Date' => '',
  'Date(-time) field options' => '',
  'Datetime' => '',
  'Default value' => '',
  'Description' => 'Deskribapena',
  'Diverse' => '',
  'E-Mail' => 'E-pota',
  'E-mail address of the user' => '',
  'Edit account' => '',
  'Editable' => '',
  'Facebook URL' => '',
  'Fax' => '',
  'Female' => '',
  'Field Type could not be changed!' => '',
  'Fieldtype' => '',
  'First name' => 'Izena',
  'Followers' => '',
  'Following' => '',
  'Friends' => 'Lagunak',
  'Gender' => '',
  'General' => 'Orokorra',
  'Hide age per default' => '',
  'Hide year in profile' => '',
  'ID' => '',
  'Instagram URL' => '',
  'Internal Name' => '',
  'Internal name already in use!' => '',
  'Internal name could not be changed!' => '',
  'Invalid field type!' => '',
  'Invalid!' => '',
  'LDAP Attribute' => '',
  'Last login date of the user' => '',
  'Last name' => 'Abizena',
  'Link Prefix (e.g. https://, mailto:, tel://)' => '',
  'LinkedIn URL' => '',
  'Male' => '',
  'Markdown' => '',
  'Mastodon URL' => '',
  'Maximum length' => '',
  'Maximum value' => '',
  'Minimum length' => '',
  'Minimum value' => '',
  'Mobile' => 'Mugikorra',
  'Module' => '',
  'Must contain at least one character.' => '',
  'Number' => '',
  'Number field options' => '',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => '',
  'Only alphanumeric characters allowed!' => '',
  'Other:' => '',
  'Phone Private' => '',
  'Phone Work' => '',
  'Please select:' => '',
  'Possible values' => '',
  'Profile Field Category' => '',
  'Regular Expression: Error message' => '',
  'Regular Expression: Validator' => '',
  'Required' => '',
  'Searchable' => '',
  'Select List' => '',
  'Select field options' => '',
  'Show at registration' => '',
  'Show date/time picker' => '',
  'Social bookmarks' => '',
  'Sort order' => '',
  'Spaces' => 'Espazioak',
  'State' => '',
  'Stream' => '',
  'Street' => '',
  'Supported ISO3166 country codes' => '',
  'Text' => '',
  'Text Area' => '',
  'Text Field Options' => '',
  'Text area field options' => '',
  'This profile is no longer available!' => '',
  'This user account is not approved yet!' => '',
  'This will add an additional input element for custom values' => '',
  'TikTok URL' => '',
  'Title' => 'Izenburua',
  'Translation Category ID' => '',
  'Twitter URL' => '',
  'Type Config' => '',
  'Updated at' => '',
  'Updated by' => '',
  'Use as Directory filter' => '',
  'Username' => 'Erabiltzaile izena',
  'Validator' => '',
  'Vimeo URL' => '',
  'Visible' => '',
  'Website URL' => '',
  'XMPP Jabber Address' => '',
  'Xing URL' => '',
  'You need to login to view this user profile!' => '',
  'YouTube URL' => '',
  'Zip' => '',
  '{attribute} is required!' => '',
);
